@@ -1,4 +1,5 @@
 #!/usr/bin/env scriptisto
+
 # Copyright 2019 The Scriptisto Authors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -13,18 +14,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
 # scriptisto-begin
 # script_src: script.py
 # build_cmd: mypy script.py && python3 -m compileall .
-# target_bin: /usr/bin/python3 @@@/script.py
+# target_interpreter: /usr/bin/env python3
+# target_bin: ./script.py
 # scriptisto-end
 
-def print_int(s: str):
+def print_str(s: str):
     print("Hello, %s!" % s)
 
 def main():
-  print_int("Python")
+  print_str("Python")
   
 if __name__== "__main__":
-  main()
\ No newline at end of file
+  main()
